From: "Zac Medico" <zmedico@gentoo.org>
To: gentoo-commits@lists.gentoo.org
Subject: [gentoo-commits] proj/portage:master commit in: repoman/
Date: Tue, 14 Nov 2017 05:02:36 +0000 (UTC) [thread overview]
Message-ID: <1510634961.f45b4973d64f6b8154eaa3a6b4b0b900ac33f1ce.zmedico@gentoo> (raw)
commit: f45b4973d64f6b8154eaa3a6b4b0b900ac33f1ce
Author: Zac Medico <zmedico <AT> gentoo <DOT> org>
AuthorDate: Tue Nov 14 04:45:20 2017 +0000
Commit: Zac Medico <zmedico <AT> gentoo <DOT> org>
CommitDate: Tue Nov 14 04:49:21 2017 +0000
URL: https://gitweb.gentoo.org/proj/portage.git/commit/?id=f45b4973
repoman/setup.py: x_sdist default root owner for archive files
repoman/setup.py | 6 +++++-
1 file changed, 5 insertions(+), 1 deletion(-)
diff --git a/repoman/setup.py b/repoman/setup.py
index 9c4def929..eead1e299 100755
--- a/repoman/setup.py
+++ b/repoman/setup.py
@@ -339,11 +339,15 @@ class x_install_scripts(install_scripts):
class x_sdist(sdist):
""" sdist defaulting to .tar.bz2 format """
def finalize_options(self):
if self.formats is None:
self.formats = ['bztar']
+ if self.owner is None:
+ self.owner = 'root'
+ if self.group is None:
+ self.group = 'root'
sdist.finalize_options(self)
next reply other threads:[~2017-11-14 5:02 UTC|newest]
Thread overview: 38+ messages / expand[flat|nested] mbox.gz Atom feed top
2017-11-14 5:02 Zac Medico [this message]
-- strict thread matches above, loose matches on Subject: below --
2021-06-05 21:08 [gentoo-commits] proj/portage:master commit in: repoman/ Zac Medico
2021-04-19 8:13 Zac Medico
2021-03-29 7:54 Zac Medico
2020-10-18 8:29 Zac Medico
2020-08-19 5:43 Zac Medico
2020-08-17 6:13 Zac Medico
2020-06-23 5:00 Zac Medico
2020-03-25 20:57 Zac Medico
2020-03-15 2:09 Zac Medico
2019-12-06 7:55 Zac Medico
2019-11-27 4:21 Zac Medico
2019-11-09 6:01 Zac Medico
2019-08-05 6:22 Zac Medico
2019-06-23 18:20 Zac Medico
2019-06-20 1:18 Zac Medico
2019-06-03 22:24 Zac Medico
2019-05-26 7:56 Zac Medico
2018-11-04 3:42 Zac Medico
2018-09-22 9:44 Zac Medico
2018-07-16 7:14 Zac Medico
2018-03-30 7:00 Zac Medico
2018-03-30 5:20 [gentoo-commits] proj/portage:repoman " Zac Medico
2018-03-30 4:23 ` [gentoo-commits] proj/portage:master " Zac Medico
2018-03-30 4:23 Zac Medico
2018-03-28 7:52 Zac Medico
2017-11-14 21:51 Zac Medico
2017-11-14 21:46 Zac Medico
2017-11-14 5:02 Zac Medico
2017-10-23 22:37 Brian Dolbec
2017-07-18 23:08 Brian Dolbec
2017-03-01 22:45 Brian Dolbec
2017-03-01 22:18 Zac Medico
2016-12-12 1:30 Brian Dolbec
2016-12-06 3:54 Brian Dolbec
2016-06-23 18:01 Brian Dolbec
2016-05-15 23:51 Brian Dolbec
2016-05-15 18:34 [gentoo-commits] proj/portage:repoman " Brian Dolbec
2016-05-15 23:51 ` [gentoo-commits] proj/portage:master " Brian Dolbec
2016-05-14 20:23 [gentoo-commits] proj/portage:repoman " Brian Dolbec
2016-05-15 23:51 ` [gentoo-commits] proj/portage:master " Brian Dolbec
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=1510634961.f45b4973d64f6b8154eaa3a6b4b0b900ac33f1ce.zmedico@gentoo \
--to=zmedico@gentoo.org \
--cc=gentoo-commits@lists.gentoo.org \
--cc=gentoo-dev@lists.gentoo.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -339,11 +339,15 @@ class x_install_scripts(install_scripts):
class x_sdist(sdist):
- """ sdist defaulting to .tar.bz2 format """
+ """ sdist defaulting to .tar.bz2 format, and archive files owned by root """
def finalize_options(self):
if self.formats is None:
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox